/// <reference types="node" />
import { Agent } from 'https';
import { TokenExtractor } from './models';
/**
 * Options for lib 'get-keycloak-public-key-with-agent'
 * @link https://github.com/andreymaznyak/node-get-keycloak-public-key
 */
export interface KeycloakCetsOptions {
    baseUrl: string;
    realm: string;
    proxyAgent?: Agent;
    expire?: number;
}
export interface ExtractorOptions {
    keycloakCetsOptions: KeycloakCetsOptions;
}
/**
 * Class for decode and verify keycloak jwt tokens
 * class have keycloak certs instanse
 */
export declare class KeycloakTokenExtractor implements TokenExtractor {
    private keyCloakCertsInstance;
    constructor(options: ExtractorOptions);
    /**
     * Method return token certs instance
     */
    getKeycloakCets(): any;
    /**
     * Method recreate token certs instance from options
     * @param options token certs lib options
     */
    setKeycloakCets(options: KeycloakCetsOptions): void;
    /**
     * Method decode token from string, and verify it with public keycloak key
     * @param token
     */
    extractToken(token: string): Promise<any>;
    /**
     * Method fetch keycloak public key and verify jwt token
     * @param kid keycloak public key id
     * @param token keycloak jwt token string
     */
    verifyToken(token: string, kid: string): Promise<any>;
}
